# A ODE solver with numpy
# Author: Nicholas Danes
import numpy as np

# initial time
t0 = 0.0

# final time
tfinal = 1000.0

# number of time steps
nt = np.loadtxt('nt.txt', dtype=int)

# step size
h = (tfinal-t0)/float(nt)
y0 = 1.0

def rhs_f(t,y):
	return -0.5*np.sin(np.power(y,2))

def heun(rhs):
	y_arr = np.zeros( nt + 1 )
	t_arr = np.zeros( nt + 1 )
	y_arr[0] = y0
	t_arr[0] = t0
	for i in range(0, nt):
		t_arr[i+1] = t0 + float(i+1)*h
		y_temp = y_arr[i] + h * rhs(t_arr[i], y_arr[i])
		y_arr[i+1] = y_arr[i] + h/2.0 * ( rhs(t_arr[i],y_arr[i]) + rhs(t_arr[i+1], y_temp) )
	return y_arr, t_arr

def main():
	y_sol, t_sol = heun(rhs_f)

if __name__ == "__main__":
    main()

